@@ -332,6 +332,9 @@ class Budget(Noise):
     references = []
     """List of reference noise classes, or (ref, cal) tuples"""
 
+    accumulate = quadsum
+    """Method used to calculate total noise trace"""
+
     def __init__(self, freq=None, noises=None, **kwargs):
         """Initialize Budget object.
 
@@ -418,13 +421,33 @@ class Budget(Noise):
         return name
 
     def __getitem__(self, name):
+        """Get a (possibly nested) sub-BudgetItem.
+
+        """
         try:
-            return self._noise_objs[name]
+            name, rest = name.split('.', 1)
+        except ValueError:
+            rest = None
+        try:
+            o = self._noise_objs[name]
         except KeyError:
             try:
-                return self._cal_objs[name]
+                o = self._cal_objs[name]
             except KeyError:
                 raise KeyError("unknown noise or cal name '{}".format(name))
+        if rest:
+            return o[rest]
+        else:
+            return o
+
+    def get(self, key, default=None):
+        """Get a (possibly nested) sub-BudgetItem.
+
+        """
+        try:
+            return self[key]
+        except KeyError:
+            return default
 
     def keys(self):
         """Iterate over budget noise names."""
@@ -501,6 +524,8 @@ class Budget(Noise):
         """
         if _precomp is None:
             _precomp = dict()
+        # must copy first if using mul-in-place or we clobber other cals
+        calibration = np.ones_like(self.freq) * calibration
         for cal in self._noise_cals[name]:
             if _cals:
                 calibration *= _cals[cal]
@@ -543,7 +568,7 @@ class Budget(Noise):
                 _precomp=_precomp,
             )
             budget.append(trace)
-        total = quadsum([trace.psd for trace in budget if trace.name in self._budget_noises])
+        total = type(self).accumulate([trace.psd for trace in budget if trace.name in self._budget_noises])
         return self._make_trace(
             psd=total, budget=budget
         )
